"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.eslintCheck = void 0;
const eslint_1 = require("eslint");
async function eslintCheck(globs, overrides) {
    const eslint = new eslint_1.ESLint({
        overrideConfig: overrides
    });
    const formatter = await eslint.loadFormatter("stylish");
    const results = await eslint.lintFiles(globs);
    const consoleOutput = formatter.format(results);
    const out = {
        consoleOutput,
        annotations: [],
        errorCount: 0,
        warningCount: 0
    };
    for (const result of results) {
        for (const message of result.messages) {
            out.errorCount += result.errorCount;
            out.warningCount += result.warningCount;
            if (message.severity !== 0) {
                let annotation = {
                    annotation_level: message.severity === 2 ? "failure" : "warning",
                    path: result.filePath,
                    title: message.ruleId || undefined,
                    message: message.message,
                    start_line: message.line || 1,
                    end_line: message.endLine || message.line || 1
                };
                if (annotation.start_line &&
                    annotation.start_line === annotation.end_line) {
                    annotation = {
                        ...annotation,
                        start_column: message.column,
                        end_column: message.endColumn || message.column
                    };
                }
                out.annotations.push(annotation);
            }
        }
    }
    return out;
}
exports.eslintCheck = eslintCheck;
