"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tslintCheck = void 0;
const tslint_1 = require("tslint");
/**
 * Get all TSLint errors and warnings for the given Typescript project.
 */
async function tslintCheck(options) {
    const program = tslint_1.Linter.createProgram(options.tsConfigFile);
    const linter = new tslint_1.Linter({
        fix: false,
        formatter: tslint_1.Formatters.CodeFrameFormatter
    }, program);
    const files = tslint_1.Linter.getFileNames(program);
    files.forEach(file => {
        var _a;
        const fileContents = ((_a = program.getSourceFile(file)) === null || _a === void 0 ? void 0 : _a.getFullText()) || "";
        const configuration = tslint_1.Configuration.findConfiguration(options.tslintConfigFile || null, file).results;
        linter.lint(file, fileContents, configuration);
    });
    const results = linter.getResult();
    const annotations = [];
    for (const failure of results.failures) {
        if (failure.getRuleSeverity() === "off") {
            continue;
        }
        let annotation = {
            annotation_level: failure.getRuleSeverity() === "error" ? "failure" : "warning",
            path: failure.getFileName(),
            title: failure.getRuleName(),
            message: failure.getFailure(),
            start_line: failure.getStartPosition().getLineAndCharacter().line + 1,
            end_line: failure.getEndPosition().getLineAndCharacter().line + 1
        };
        if (annotation.start_line &&
            annotation.start_line === annotation.end_line) {
            annotation = {
                ...annotation,
                start_column: failure.getStartPosition().getLineAndCharacter().character + 1,
                end_column: failure.getEndPosition().getLineAndCharacter().character + 1
            };
        }
        annotations.push(annotation);
    }
    return {
        consoleOutput: results.output,
        annotations,
        errorCount: results.errorCount,
        warningCount: results.warningCount
    };
}
exports.tslintCheck = tslintCheck;
