"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.typescriptCheck = void 0;
const ts = __importStar(require("typescript"));
/**
 * Get all Typescript compiler diagnostics for the given TS project.
 */
async function typescriptCheck(configFileName) {
    var _a, _b, _c;
    const diagnosticHost = {
        getCurrentDirectory: ts.sys.getCurrentDirectory,
        getNewLine: () => ts.sys.newLine,
        getCanonicalFileName: (s) => s
    };
    const parsedCommandLine = ts.getParsedCommandLineOfConfigFile(configFileName, {}, {
        ...ts.sys,
        onUnRecoverableConfigFileDiagnostic: (diagnostic) => {
            ts.formatDiagnostic(diagnostic, diagnosticHost);
        }
    });
    const program = ts.createProgram((parsedCommandLine === null || parsedCommandLine === void 0 ? void 0 : parsedCommandLine.fileNames) || [], {
        ...parsedCommandLine === null || parsedCommandLine === void 0 ? void 0 : parsedCommandLine.options,
        noEmit: true
    });
    const emitResult = program.emit();
    const allDiagnostics = ts
        .getPreEmitDiagnostics(program)
        .concat(emitResult.diagnostics);
    const annotations = [];
    const globalErrors = [];
    let errorCount = 0;
    let warningCount = 0;
    for (const diagnostic of allDiagnostics) {
        if (diagnostic.category === ts.DiagnosticCategory.Error) {
            errorCount++;
        }
        else if (diagnostic.category === ts.DiagnosticCategory.Warning) {
            warningCount++;
        }
        if (diagnostic.file) {
            const start = diagnostic.file.getLineAndCharacterOfPosition((_a = diagnostic.start) !== null && _a !== void 0 ? _a : 0);
            const end = diagnostic.file.getLineAndCharacterOfPosition(((_b = diagnostic.start) !== null && _b !== void 0 ? _b : 0) + ((_c = diagnostic.length) !== null && _c !== void 0 ? _c : 0));
            annotations.push({
                annotation_level: diagnostic.category === ts.DiagnosticCategory.Error
                    ? "failure"
                    : diagnostic.category === ts.DiagnosticCategory.Warning
                        ? "warning"
                        : "notice",
                start_line: start.line + 1,
                end_line: end.line + 1,
                message: ts.flattenDiagnosticMessageText(diagnostic.messageText, "\n"),
                path: diagnostic.file.fileName
            });
        }
        else if (diagnostic.category === ts.DiagnosticCategory.Error) {
            globalErrors.push(ts.flattenDiagnosticMessageText(diagnostic.messageText, "\n"));
        }
    }
    let consoleOutput = ts.formatDiagnosticsWithColorAndContext(allDiagnostics, diagnosticHost);
    if (globalErrors.length > 0) {
        consoleOutput = `${globalErrors.join("\n")}\n${consoleOutput}`;
    }
    return {
        errorCount,
        warningCount,
        annotations,
        consoleOutput
    };
}
exports.typescriptCheck = typescriptCheck;
